@@ -42,7 +42,7 @@ class GUI : public QMainWindow
 	Q_OBJECT
 
 public:
-	GUI();
+	GUI(const QString &lang);
 
 	bool openFile(const QString &fileName, bool tryUnknown, int &showError);
 	bool loadMap(const QString &fileName, MapAction *&action, int &showError);
@@ -99,6 +99,9 @@ private slots:
 	void clearRecentFiles();
 #endif // Q_OS_ANDROID
 
+	void nextTab();
+	void prevTab();
+
 	void next();
 	void prev();
 	void last();
@@ -169,6 +172,7 @@ private:
 	bool updateGraphTabs();
 	void updateDataDEMDownloadAction();
 	void updateMapDEMDownloadAction();
+	void updateMapLayers();
 #ifndef Q_OS_ANDROID
 	void updateRecentFiles(const QString &fileName);
 #endif // Q_OS_ANDROID
@@ -207,6 +211,8 @@ private:
 	void dragEnterEvent(QDragEnterEvent *event);
 	void dropEvent(QDropEvent *event);
 
+	QString _lang;
+
 #ifdef Q_OS_ANDROID
 	NavigationWidget *_navigation;
 #else // Q_OS_ANDROID
@@ -216,6 +222,7 @@ private:
 #endif // Q_OS_ANDROID
 	QMenu *_poiMenu;
 	QMenu *_mapMenu;
+	QMenu *_mapLayersMenu;
 #ifndef Q_OS_ANDROID
 	QMenu *_recentFilesMenu;
 #endif // Q_OS_ANDROID
@@ -279,8 +286,6 @@ private:
 	QAction *_dmsAction;
 	QAction *_totalTimeAction;
 	QAction *_movingTimeAction;
-	QAction *_nextMapAction;
-	QAction *_prevMapAction;
 	QAction *_showTracksAction;
 	QAction *_showRoutesAction;
 	QAction *_showWaypointsAction;
@@ -301,15 +306,13 @@ private:
 	QAction *_downloadMapDEMAction;
 	QAction *_showDEMTilesAction;
 	QAction *_drawHillShadingAction;
-	QAction *_drawRastersAction;
-	QAction *_drawVectorsAction;
-	QAction *_drawAllAction;
 	QAction *_mapsEnd;
 	QAction *_poisEnd;
 #ifndef Q_OS_ANDROID
 	QAction *_clearRecentFilesAction;
 	QAction *_recentFilesEnd;
 #endif // Q_OS_ANDROID
+	QActionGroup *_mapLayersActionGroup;
 
 	QLabel *_fileNameLabel;
 	QLabel *_distanceLabel;
